@@ -20,8 +20,10 @@ import os
 import logging
 import copy
 import pathlib
+from contextlib import ExitStack
 from collections import OrderedDict
 from collections import namedtuple
+from textwrap import dedent
 from typing import (
     Any, List, Optional, Dict
 )
@@ -55,6 +57,7 @@ from kiwi.builder.template.container_import import BuilderTemplateSystemdUnit
 from kiwi.system.profile import Profile
 
 from kiwi.exceptions import (
+    KiwiCommandError,
     KiwiImportDescriptionError,
     KiwiScriptFailed,
     KiwiFileNotFound
@@ -385,10 +388,26 @@ class SystemSetup:
                 root=self.root_dir, raise_on_error=False
             ):
                 Path.wipe(self.root_dir + '/etc/vconsole.conf')
-                Command.run([
+                res = Command.run([
                     'chroot', self.root_dir, 'systemd-firstboot',
-                    '--keymap=' + self.preferences['keytable']
-                ])
+                    '--keymap=' + self.preferences['keytable'],
+                ], raise_on_error=False)
+                if res.returncode != 0:
+                    message = dedent(f'''\n
+                        keyboard setup skipped because `systemd-firstboot --keymap` failed (code {res.returncode}):
+                        {res.error}
+
+                        This can happen for example if the specified keytable ({self.preferences['keytable']}) is not available,
+                        or if your system does not support the systemd way of managing keymaps.
+                        Note that in both cases, systemd-firstboot's error message complains that the keymap is not installed.
+
+                        If the keytable is missing, you might be able to install it for example via an additional package.
+                        If your system doesn't support systemd's keymap management,
+                        then you can use a distribution-specific method to set the keymap in a config.sh script.
+
+                        You can try `localectl list-keymaps` to see if a particular distro supports systemd keymap management.
+                    ''')
+                    raise KiwiCommandError(message)
             elif os.path.exists(self.root_dir + '/etc/sysconfig/keyboard'):
                 Shell.run_common_function(
                     'baseUpdateSysConfig', [
@@ -753,7 +772,8 @@ class SystemSetup:
         Call disk.sh script chrooted
         """
         self._call_script(
-            defaults.POST_DISK_SYNC_SCRIPT
+            defaults.POST_DISK_SYNC_SCRIPT,
+            root_is_mountpoint=True
         )
 
     def call_pre_disk_script(self) -> None:
@@ -1260,38 +1280,54 @@ class SystemSetup:
             )
 
     def _call_script(
-        self, name, option_list=None, path_prefix=defaults.IMAGE_METADATA_DIR
+        self,
+        name: str,
+        option_list: List[str] = [],
+        path_prefix: str = defaults.IMAGE_METADATA_DIR,
+        root_is_mountpoint: bool = False
     ):
-        script_path = os.path.join(self.root_dir, path_prefix, name)
-        if os.path.exists(script_path):
-            options = option_list or []
-            if log.getLogFlags().get('run-scripts-in-screen'):
-                # Run scripts in a screen session if requested
-                command = ['screen', '-t', '-X', 'chroot', self.root_dir]
-            else:
-                # In standard mode run scripts without a terminal
-                # associated to them
-                command = ['chroot', self.root_dir]
-            if not Path.access(script_path, os.X_OK):
-                command.append('bash')
-            command.append(
-                os.path.join(os.sep, path_prefix, name)
-            )
-            command.extend(options)
-            profile = Profile(self.xml_state)
-            caller_environment = copy.deepcopy(os.environ)
-            caller_environment.update(profile.get_settings())
-            config_script = Command.call(command, caller_environment)
-            process = CommandProcess(
-                command=config_script, log_topic='Calling ' + name + ' script'
-            )
-            result = process.poll_and_watch()
-            if result.returncode != 0:
-                raise KiwiScriptFailed(
-                    '{0} failed: {1}'.format(name, result.stderr)
+        with ExitStack() as stack:
+            script_path = os.path.join(self.root_dir, path_prefix, name)
+            if os.path.exists(script_path):
+                if root_is_mountpoint:
+                    chroot_mount = MountManager(
+                        device=self.root_dir, mountpoint=self.root_dir
+                    )
+                    if not chroot_mount.is_mounted():
+                        log.debug(
+                            f'Self bind mount {self.root_dir} for (/) in chroot'
+                        )
+                        chroot_mount.bind_mount()
+                        stack.push(chroot_mount)
+                options = option_list or []
+                if log.getLogFlags().get('run-scripts-in-screen'):
+                    # Run scripts in a screen session if requested
+                    command = ['screen', '-t', '-X', 'chroot', self.root_dir]
+                else:
+                    # In standard mode run scripts without a terminal
+                    # associated to them
+                    command = ['chroot', self.root_dir]
+                if not Path.access(script_path, os.X_OK):
+                    command.append('bash')
+                command.append(
+                    os.path.join(os.sep, path_prefix, name)
                 )
-            # if configured, assign SELinux labels
-            self.setup_selinux_file_contexts()
+                command.extend(options)
+                profile = Profile(self.xml_state)
+                caller_environment = copy.deepcopy(os.environ)
+                caller_environment.update(profile.get_settings())
+                config_script = Command.call(command, caller_environment)
+                process = CommandProcess(
+                    command=config_script,
+                    log_topic='Calling ' + name + ' script'
+                )
+                result = process.poll_and_watch()
+                if result.returncode != 0:
+                    raise KiwiScriptFailed(
+                        f'{name} failed with: {result.stderr}'
+                    )
+                # if configured, assign SELinux labels
+                self.setup_selinux_file_contexts()
 
     def _call_script_no_chroot(
         self, name: str, option_list: List[str], working_directory: Optional[str]
