@@ -3,7 +3,7 @@ import os
 import logging
 import io
 from unittest.mock import (
-    patch, call, Mock, MagicMock, mock_open
+    ANY, DEFAULT, patch, call, Mock, MagicMock, mock_open
 )
 from pytest import (
     raises, fixture
@@ -18,11 +18,14 @@ from kiwi.xml_state import XMLState
 from kiwi.defaults import Defaults
 
 from kiwi.exceptions import (
+    KiwiCommandError,
     KiwiScriptFailed,
     KiwiImportDescriptionError,
     KiwiFileNotFound
 )
 
+from kiwi.command import CommandT
+
 
 class TestSystemSetup:
     @fixture(autouse=True)
@@ -543,6 +546,7 @@ class TestSystemSetup:
     ):
         mock_caps.return_value = True
         mock_path.return_value = True
+        mock_run.return_value = CommandT("", "", 0)
         self.setup.preferences['keytable'] = 'keytable'
         self.setup.setup_keyboard_map()
         mock_run.assert_has_calls([
@@ -550,7 +554,7 @@ class TestSystemSetup:
             call([
                 'chroot', 'root_dir', 'systemd-firstboot',
                 '--keymap=keytable'
-            ])
+            ], raise_on_error=False)
         ])
 
     @patch('os.path.exists')
@@ -562,6 +566,22 @@ class TestSystemSetup:
         with self._caplog.at_level(logging.WARNING):
             self.setup.setup_keyboard_map()
 
+    @patch('kiwi.system.setup.CommandCapabilities.has_option_in_help')
+    @patch('kiwi.system.setup.Command.run')
+    def test_setup_keyboard_skipped_systemd_incompatible(self, mock_run, mock_caps):
+        mock_caps.return_value = True  # systemd-firstboot --keymap found in help
+        self.setup.preferences['keytable'] = 'keytable'
+
+        # mock the Command.run for `localectl list-keymaps`
+        def side_effect(args, **kwargs):
+            if args == ['chroot', ANY, 'systemd-firstboot', '--keymap=keytable']:
+                return CommandT("", "Keymap us is not installed.", 1)
+            return DEFAULT
+        mock_run.side_effect = side_effect
+        with raises(KiwiCommandError) as excinfo:
+            self.setup.setup_keyboard_map()
+        assert 'your system does not support the systemd way of managing keymaps' in str(excinfo.value)
+
     @patch('kiwi.system.setup.CommandCapabilities.has_option_in_help')
     @patch('kiwi.system.setup.Command.run')
     @patch('os.path.exists')
@@ -873,11 +893,24 @@ class TestSystemSetup:
     @patch('os.stat')
     @patch('os.access')
     @patch('copy.deepcopy')
+    @patch('kiwi.system.setup.MountManager')
     def test_call_disk_script(
-        self, mock_copy_deepcopy, mock_access, mock_stat, mock_os_path,
-        mock_watch, mock_command, mock_Profile, mock_getLogFlags,
-        mock_is_buildservice_worker, mock_setup_selinux_file_contexts
+        self,
+        mock_MountManager,
+        mock_copy_deepcopy,
+        mock_access,
+        mock_stat,
+        mock_os_path,
+        mock_watch,
+        mock_command,
+        mock_Profile,
+        mock_getLogFlags,
+        mock_is_buildservice_worker,
+        mock_setup_selinux_file_contexts
     ):
+        chroot_mount = Mock()
+        chroot_mount.is_mounted.return_value = False
+        mock_MountManager.return_value = chroot_mount
         mock_is_buildservice_worker.return_value = False
         mock_getLogFlags.return_value = {
             'run-scripts-in-screen': True
@@ -903,6 +936,10 @@ class TestSystemSetup:
             ], {}
         )
         mock_setup_selinux_file_contexts.assert_called_once_with()
+        mock_MountManager.assert_called_once_with(
+            device='root_dir', mountpoint='root_dir'
+        )
+        chroot_mount.bind_mount.assert_called_once_with()
 
     @patch.object(SystemSetup, 'setup_selinux_file_contexts')
     @patch('kiwi.system.setup.Defaults.is_buildservice_worker')
